# coding: utf-8

"""
    ORY Keto

    Ory Keto is a cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: Latest
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_keto_client.configuration import Configuration


class OryAccessControlPolicy(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'actions': 'list[str]',
        'conditions': 'dict(str, object)',
        'description': 'str',
        'effect': 'str',
        'id': 'str',
        'resources': 'list[str]',
        'subjects': 'list[str]'
    }

    attribute_map = {
        'actions': 'actions',
        'conditions': 'conditions',
        'description': 'description',
        'effect': 'effect',
        'id': 'id',
        'resources': 'resources',
        'subjects': 'subjects'
    }

    def __init__(self, actions=None, conditions=None, description=None, effect=None, id=None, resources=None, subjects=None, local_vars_configuration=None):  # noqa: E501
        """OryAccessControlPolicy - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._actions = None
        self._conditions = None
        self._description = None
        self._effect = None
        self._id = None
        self._resources = None
        self._subjects = None
        self.discriminator = None

        if actions is not None:
            self.actions = actions
        if conditions is not None:
            self.conditions = conditions
        if description is not None:
            self.description = description
        if effect is not None:
            self.effect = effect
        if id is not None:
            self.id = id
        if resources is not None:
            self.resources = resources
        if subjects is not None:
            self.subjects = subjects

    @property
    def actions(self):
        """Gets the actions of this OryAccessControlPolicy.  # noqa: E501

        Actions is an array representing all the actions this ORY Access Policy applies to.  # noqa: E501

        :return: The actions of this OryAccessControlPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this OryAccessControlPolicy.

        Actions is an array representing all the actions this ORY Access Policy applies to.  # noqa: E501

        :param actions: The actions of this OryAccessControlPolicy.  # noqa: E501
        :type: list[str]
        """

        self._actions = actions

    @property
    def conditions(self):
        """Gets the conditions of this OryAccessControlPolicy.  # noqa: E501

        Conditions represents a keyed object of conditions under which this ORY Access Policy is active.  # noqa: E501

        :return: The conditions of this OryAccessControlPolicy.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this OryAccessControlPolicy.

        Conditions represents a keyed object of conditions under which this ORY Access Policy is active.  # noqa: E501

        :param conditions: The conditions of this OryAccessControlPolicy.  # noqa: E501
        :type: dict(str, object)
        """

        self._conditions = conditions

    @property
    def description(self):
        """Gets the description of this OryAccessControlPolicy.  # noqa: E501

        Description is an optional, human-readable description.  # noqa: E501

        :return: The description of this OryAccessControlPolicy.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this OryAccessControlPolicy.

        Description is an optional, human-readable description.  # noqa: E501

        :param description: The description of this OryAccessControlPolicy.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def effect(self):
        """Gets the effect of this OryAccessControlPolicy.  # noqa: E501

        Effect is the effect of this ORY Access Policy. It can be \"allow\" or \"deny\".  # noqa: E501

        :return: The effect of this OryAccessControlPolicy.  # noqa: E501
        :rtype: str
        """
        return self._effect

    @effect.setter
    def effect(self, effect):
        """Sets the effect of this OryAccessControlPolicy.

        Effect is the effect of this ORY Access Policy. It can be \"allow\" or \"deny\".  # noqa: E501

        :param effect: The effect of this OryAccessControlPolicy.  # noqa: E501
        :type: str
        """

        self._effect = effect

    @property
    def id(self):
        """Gets the id of this OryAccessControlPolicy.  # noqa: E501

        ID is the unique identifier of the ORY Access Policy. It is used to query, update, and remove the ORY Access Policy.  # noqa: E501

        :return: The id of this OryAccessControlPolicy.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OryAccessControlPolicy.

        ID is the unique identifier of the ORY Access Policy. It is used to query, update, and remove the ORY Access Policy.  # noqa: E501

        :param id: The id of this OryAccessControlPolicy.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def resources(self):
        """Gets the resources of this OryAccessControlPolicy.  # noqa: E501

        Resources is an array representing all the resources this ORY Access Policy applies to.  # noqa: E501

        :return: The resources of this OryAccessControlPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this OryAccessControlPolicy.

        Resources is an array representing all the resources this ORY Access Policy applies to.  # noqa: E501

        :param resources: The resources of this OryAccessControlPolicy.  # noqa: E501
        :type: list[str]
        """

        self._resources = resources

    @property
    def subjects(self):
        """Gets the subjects of this OryAccessControlPolicy.  # noqa: E501

        Subjects is an array representing all the subjects this ORY Access Policy applies to.  # noqa: E501

        :return: The subjects of this OryAccessControlPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._subjects

    @subjects.setter
    def subjects(self, subjects):
        """Sets the subjects of this OryAccessControlPolicy.

        Subjects is an array representing all the subjects this ORY Access Policy applies to.  # noqa: E501

        :param subjects: The subjects of this OryAccessControlPolicy.  # noqa: E501
        :type: list[str]
        """

        self._subjects = subjects

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OryAccessControlPolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OryAccessControlPolicy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ORY Keto

    Ory Keto is a cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: Latest
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_keto_client.configuration import Configuration


class OryAccessControlPolicyAllowedInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action': 'str',
        'context': 'dict(str, object)',
        'resource': 'str',
        'subject': 'str'
    }

    attribute_map = {
        'action': 'action',
        'context': 'context',
        'resource': 'resource',
        'subject': 'subject'
    }

    def __init__(self, action=None, context=None, resource=None, subject=None, local_vars_configuration=None):  # noqa: E501
        """OryAccessControlPolicyAllowedInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action = None
        self._context = None
        self._resource = None
        self._subject = None
        self.discriminator = None

        if action is not None:
            self.action = action
        if context is not None:
            self.context = context
        if resource is not None:
            self.resource = resource
        if subject is not None:
            self.subject = subject

    @property
    def action(self):
        """Gets the action of this OryAccessControlPolicyAllowedInput.  # noqa: E501

        Action is the action that is requested on the resource.  # noqa: E501

        :return: The action of this OryAccessControlPolicyAllowedInput.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this OryAccessControlPolicyAllowedInput.

        Action is the action that is requested on the resource.  # noqa: E501

        :param action: The action of this OryAccessControlPolicyAllowedInput.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def context(self):
        """Gets the context of this OryAccessControlPolicyAllowedInput.  # noqa: E501

        Context is the request's environmental context.  # noqa: E501

        :return: The context of this OryAccessControlPolicyAllowedInput.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this OryAccessControlPolicyAllowedInput.

        Context is the request's environmental context.  # noqa: E501

        :param context: The context of this OryAccessControlPolicyAllowedInput.  # noqa: E501
        :type: dict(str, object)
        """

        self._context = context

    @property
    def resource(self):
        """Gets the resource of this OryAccessControlPolicyAllowedInput.  # noqa: E501

        Resource is the resource that access is requested to.  # noqa: E501

        :return: The resource of this OryAccessControlPolicyAllowedInput.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this OryAccessControlPolicyAllowedInput.

        Resource is the resource that access is requested to.  # noqa: E501

        :param resource: The resource of this OryAccessControlPolicyAllowedInput.  # noqa: E501
        :type: str
        """

        self._resource = resource

    @property
    def subject(self):
        """Gets the subject of this OryAccessControlPolicyAllowedInput.  # noqa: E501

        Subject is the subject that is requesting access.  # noqa: E501

        :return: The subject of this OryAccessControlPolicyAllowedInput.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this OryAccessControlPolicyAllowedInput.

        Subject is the subject that is requesting access.  # noqa: E501

        :param subject: The subject of this OryAccessControlPolicyAllowedInput.  # noqa: E501
        :type: str
        """

        self._subject = subject

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OryAccessControlPolicyAllowedInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OryAccessControlPolicyAllowedInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ORY Keto

    Ory Keto is a cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: Latest
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ory_keto_client.api_client import ApiClient
from ory_keto_client.exceptions import (
    ApiTypeError,
    ApiValueError
)


class EnginesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_ory_access_control_policy_role_members(self, flavor, id, **kwargs):  # noqa: E501
        """Add a member to an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_ory_access_control_policy_role_members(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param AddOryAccessControlPolicyRoleMembersBody body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OryAccessControlPolicyRole
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_ory_access_control_policy_role_members_with_http_info(flavor, id, **kwargs)  # noqa: E501

    def add_ory_access_control_policy_role_members_with_http_info(self, flavor, id, **kwargs):  # noqa: E501
        """Add a member to an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_ory_access_control_policy_role_members_with_http_info(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param AddOryAccessControlPolicyRoleMembersBody body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OryAccessControlPolicyRole, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_ory_access_control_policy_role_members" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `add_ory_access_control_policy_role_members`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `add_ory_access_control_policy_role_members`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/roles/{id}/members', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OryAccessControlPolicyRole',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_ory_access_control_policy(self, flavor, id, **kwargs):  # noqa: E501
        """delete_ory_access_control_policy  # noqa: E501

        Delete an ORY Access Control Policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ory_access_control_policy(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_ory_access_control_policy_with_http_info(flavor, id, **kwargs)  # noqa: E501

    def delete_ory_access_control_policy_with_http_info(self, flavor, id, **kwargs):  # noqa: E501
        """delete_ory_access_control_policy  # noqa: E501

        Delete an ORY Access Control Policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ory_access_control_policy_with_http_info(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_ory_access_control_policy" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `delete_ory_access_control_policy`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `delete_ory_access_control_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/policies/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_ory_access_control_policy_role(self, flavor, id, **kwargs):  # noqa: E501
        """Delete an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ory_access_control_policy_role(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_ory_access_control_policy_role_with_http_info(flavor, id, **kwargs)  # noqa: E501

    def delete_ory_access_control_policy_role_with_http_info(self, flavor, id, **kwargs):  # noqa: E501
        """Delete an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ory_access_control_policy_role_with_http_info(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_ory_access_control_policy_role" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `delete_ory_access_control_policy_role`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `delete_ory_access_control_policy_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/roles/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def do_ory_access_control_policies_allow(self, flavor, **kwargs):  # noqa: E501
        """Check if a request is allowed  # noqa: E501

        Use this endpoint to check if a request is allowed or not. If the request is allowed, a 200 response with `{\"allowed\":\"true\"}` will be sent. If the request is denied, a 403 response with `{\"allowed\":\"false\"}` will be sent instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.do_ory_access_control_policies_allow(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param OryAccessControlPolicyAllowedInput body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AuthorizationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.do_ory_access_control_policies_allow_with_http_info(flavor, **kwargs)  # noqa: E501

    def do_ory_access_control_policies_allow_with_http_info(self, flavor, **kwargs):  # noqa: E501
        """Check if a request is allowed  # noqa: E501

        Use this endpoint to check if a request is allowed or not. If the request is allowed, a 200 response with `{\"allowed\":\"true\"}` will be sent. If the request is denied, a 403 response with `{\"allowed\":\"false\"}` will be sent instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.do_ory_access_control_policies_allow_with_http_info(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param OryAccessControlPolicyAllowedInput body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AuthorizationResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method do_ory_access_control_policies_allow" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `do_ory_access_control_policies_allow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/allowed', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AuthorizationResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ory_access_control_policy(self, flavor, id, **kwargs):  # noqa: E501
        """get_ory_access_control_policy  # noqa: E501

        Get an ORY Access Control Policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ory_access_control_policy(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OryAccessControlPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_ory_access_control_policy_with_http_info(flavor, id, **kwargs)  # noqa: E501

    def get_ory_access_control_policy_with_http_info(self, flavor, id, **kwargs):  # noqa: E501
        """get_ory_access_control_policy  # noqa: E501

        Get an ORY Access Control Policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ory_access_control_policy_with_http_info(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OryAccessControlPolicy, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ory_access_control_policy" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `get_ory_access_control_policy`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_ory_access_control_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/policies/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OryAccessControlPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ory_access_control_policy_role(self, flavor, id, **kwargs):  # noqa: E501
        """Get an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ory_access_control_policy_role(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OryAccessControlPolicyRole
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_ory_access_control_policy_role_with_http_info(flavor, id, **kwargs)  # noqa: E501

    def get_ory_access_control_policy_role_with_http_info(self, flavor, id, **kwargs):  # noqa: E501
        """Get an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ory_access_control_policy_role_with_http_info(flavor, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OryAccessControlPolicyRole, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ory_access_control_policy_role" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `get_ory_access_control_policy_role`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_ory_access_control_policy_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/roles/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OryAccessControlPolicyRole',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_ory_access_control_policies(self, flavor, **kwargs):  # noqa: E501
        """list_ory_access_control_policies  # noqa: E501

        List ORY Access Control Policies  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_ory_access_control_policies(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\" (required)
        :param int limit: The maximum amount of policies returned.
        :param int offset: The offset from where to start looking.
        :param str subject: The subject for whom the policies are to be listed.
        :param str resource: The resource for which the policies are to be listed.
        :param str action: The action for which policies are to be listed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[OryAccessControlPolicy]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_ory_access_control_policies_with_http_info(flavor, **kwargs)  # noqa: E501

    def list_ory_access_control_policies_with_http_info(self, flavor, **kwargs):  # noqa: E501
        """list_ory_access_control_policies  # noqa: E501

        List ORY Access Control Policies  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_ory_access_control_policies_with_http_info(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\" (required)
        :param int limit: The maximum amount of policies returned.
        :param int offset: The offset from where to start looking.
        :param str subject: The subject for whom the policies are to be listed.
        :param str resource: The resource for which the policies are to be listed.
        :param str action: The action for which policies are to be listed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[OryAccessControlPolicy], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'limit', 'offset', 'subject', 'resource', 'action']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_ory_access_control_policies" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `list_ory_access_control_policies`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'subject' in local_var_params and local_var_params['subject'] is not None:  # noqa: E501
            query_params.append(('subject', local_var_params['subject']))  # noqa: E501
        if 'resource' in local_var_params and local_var_params['resource'] is not None:  # noqa: E501
            query_params.append(('resource', local_var_params['resource']))  # noqa: E501
        if 'action' in local_var_params and local_var_params['action'] is not None:  # noqa: E501
            query_params.append(('action', local_var_params['action']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/policies', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OryAccessControlPolicy]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_ory_access_control_policy_roles(self, flavor, **kwargs):  # noqa: E501
        """List ORY Access Control Policy Roles  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_ory_access_control_policy_roles(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\" (required)
        :param int limit: The maximum amount of policies returned.
        :param int offset: The offset from where to start looking.
        :param str member: The member for which the roles are to be listed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[OryAccessControlPolicyRole]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_ory_access_control_policy_roles_with_http_info(flavor, **kwargs)  # noqa: E501

    def list_ory_access_control_policy_roles_with_http_info(self, flavor, **kwargs):  # noqa: E501
        """List ORY Access Control Policy Roles  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_ory_access_control_policy_roles_with_http_info(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\" (required)
        :param int limit: The maximum amount of policies returned.
        :param int offset: The offset from where to start looking.
        :param str member: The member for which the roles are to be listed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[OryAccessControlPolicyRole], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'limit', 'offset', 'member']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_ory_access_control_policy_roles" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `list_ory_access_control_policy_roles`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'member' in local_var_params and local_var_params['member'] is not None:  # noqa: E501
            query_params.append(('member', local_var_params['member']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/roles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OryAccessControlPolicyRole]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_ory_access_control_policy_role_members(self, flavor, id, member, **kwargs):  # noqa: E501
        """Remove a member from an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_ory_access_control_policy_role_members(flavor, id, member, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param str member: The member to be removed. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_ory_access_control_policy_role_members_with_http_info(flavor, id, member, **kwargs)  # noqa: E501

    def remove_ory_access_control_policy_role_members_with_http_info(self, flavor, id, member, **kwargs):  # noqa: E501
        """Remove a member from an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_ory_access_control_policy_role_members_with_http_info(flavor, id, member, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param str id: The ID of the ORY Access Control Policy Role. (required)
        :param str member: The member to be removed. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'id', 'member']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_ory_access_control_policy_role_members" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `remove_ory_access_control_policy_role_members`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `remove_ory_access_control_policy_role_members`")  # noqa: E501
        # verify the required parameter 'member' is set
        if self.api_client.client_side_validation and ('member' not in local_var_params or  # noqa: E501
                                                        local_var_params['member'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `member` when calling `remove_ory_access_control_policy_role_members`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501
        if 'member' in local_var_params:
            path_params['member'] = local_var_params['member']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/roles/{id}/members/{member}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upsert_ory_access_control_policy(self, flavor, **kwargs):  # noqa: E501
        """upsert_ory_access_control_policy  # noqa: E501

        Upsert an ORY Access Control Policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upsert_ory_access_control_policy(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param OryAccessControlPolicy body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OryAccessControlPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upsert_ory_access_control_policy_with_http_info(flavor, **kwargs)  # noqa: E501

    def upsert_ory_access_control_policy_with_http_info(self, flavor, **kwargs):  # noqa: E501
        """upsert_ory_access_control_policy  # noqa: E501

        Upsert an ORY Access Control Policy  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upsert_ory_access_control_policy_with_http_info(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param OryAccessControlPolicy body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OryAccessControlPolicy, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upsert_ory_access_control_policy" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `upsert_ory_access_control_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/policies', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OryAccessControlPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upsert_ory_access_control_policy_role(self, flavor, **kwargs):  # noqa: E501
        """Upsert an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upsert_ory_access_control_policy_role(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param OryAccessControlPolicyRole body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OryAccessControlPolicyRole
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upsert_ory_access_control_policy_role_with_http_info(flavor, **kwargs)  # noqa: E501

    def upsert_ory_access_control_policy_role_with_http_info(self, flavor, **kwargs):  # noqa: E501
        """Upsert an ORY Access Control Policy Role  # noqa: E501

        Roles group several subjects into one. Rules can be assigned to ORY Access Control Policy (OACP) by using the Role ID as subject in the OACP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upsert_ory_access_control_policy_role_with_http_info(flavor, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str flavor: The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\". (required)
        :param OryAccessControlPolicyRole body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OryAccessControlPolicyRole, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['flavor', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upsert_ory_access_control_policy_role" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'flavor' is set
        if self.api_client.client_side_validation and ('flavor' not in local_var_params or  # noqa: E501
                                                        local_var_params['flavor'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `flavor` when calling `upsert_ory_access_control_policy_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'flavor' in local_var_params:
            path_params['flavor'] = local_var_params['flavor']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/engines/acp/ory/{flavor}/roles', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OryAccessControlPolicyRole',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
